==> ToolChain_STM32_1.0.49.tar.bz: ToolChain_STM32_1.0.49/Template/examples/example_i2c.h <==
#ifndef EXAMPLE_I2C_H
#define EXAMPLE_I2C_H

/*{ example_i2c.h ******************************************************
 
                       The ToolChain
                       
 Example code demonstrating how to use 
 Universal Synchronous Asynchronous Receiver Transmitter (I2C)
 
 written by Gregor Rebel 2012
 
}*/
//{ Defines/ TypeDefs ****************************************************


//} Defines
//{ Includes *************************************************************

 // Basic set of helper functions
#include "ttc_basic.h"
#include "ttc_i2c.h"
#include "ttc_gpio.h"
#include "ttc_task.h"

#ifdef EXTENSION_400_lcd_320x240_olimex
#include "lcd-320x240.h"
#endif
#ifdef EXTENSION_400_sensor_lis3lv02dl
#include "common/sensors/accelerometer/lis3lv02dl.h" // accelerometer embedded into STM32-LCD prototype board
#endif

//} Includes
//{ Structures/ Enums ****************************************************

//} Structures/ Enums
//{ Global Variables *****************************************************



//} Global Variables
//{ Function prototypes **************************************************

/* Call before example_i2c_start() to initialize hardware.
 */
void example_i2c_init();

/* initializes + starts I2C example
 */
void example_i2c_start();

/* Sends "Hello World" to initialized I2C
 */
void task_I2C_master(void *pvParameters);

/* Reads from initialized I2C and sends answer
 */
void task_I2C_slave(void *pvParameters);

/* processes received data */
void processData(char* Data, u8_t MaxLength);

/* send given buffer */
void sendData(const char* Buffer, u16_t MaxLength);

//} Function prototypes

#endif //EXAMPLE_I2C_H

==> ToolChain_STM32_1.0.50.tar.bz: ToolChain_STM32_1.0.50/Template/examples/example_i2c.h <==
#ifndef EXAMPLE_I2C_H
#define EXAMPLE_I2C_H

/*{ example_i2c.h ******************************************************
 
                       The ToolChain
                       
 Example code demonstrating how to use 
 Universal Synchronous Asynchronous Receiver Transmitter (I2C)
 
 written by Gregor Rebel 2012
 
}*/
//{ Defines/ TypeDefs ****************************************************


//} Defines
//{ Includes *************************************************************

 // Basic set of helper functions
#include "ttc_basic.h"
#include "ttc_i2c.h"
#include "ttc_gpio.h"
#include "ttc_task.h"

#ifdef EXTENSION_400_lcd_320x240_K320QVB
#include "lcd-320x240.h"
#endif
#ifdef EXTENSION_400_sensor_lis3lv02dl
#include "common/sensors/accelerometer/lis3lv02dl.h" // accelerometer embedded into STM32-LCD prototype board
#endif

//} Includes
//{ Structures/ Enums ****************************************************

//} Structures/ Enums
//{ Global Variables *****************************************************



//} Global Variables
//{ Function prototypes **************************************************

/* Call before example_i2c_start() to initialize hardware.
 */
void example_i2c_init();

/* initializes + starts I2C example
 */
void example_i2c_start();

/* Sends "Hello World" to initialized I2C
 */
void task_I2C_master(void *pvParameters);

/* Reads from initialized I2C and sends answer
 */
void task_I2C_slave(void *pvParameters);

/* processes received data */
void processData(char* Data, u8_t MaxLength);

/* send given buffer */
void sendData(const char* Buffer, u16_t MaxLength);

//} Function prototypes

#endif //EXAMPLE_I2C_H
